==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_entities/laborbooking_001/LaborBooking.java <==

package net.datastream.schemas.mp_entities.laborbooking_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.BOOKEDHOURSID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.MULTIEQUIPSPLITINFOBATCH;
import net.datastream.schemas.mp_fields.OCCUPATIONTYPEID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOOKEDHOURSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEWORKED"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOURSWORKED"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CORRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIPSPLITINFOBATCH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOWZERORATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CORRECTIONDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "bookedhoursid",
    "activityid",
    "tradeid",
    "departmentid",
    "dateworked",
    "occupationtype",
    "employee",
    "traderate",
    "hoursworked",
    "starttime",
    "endtime",
    "correction",
    "multiequipsplitinfobatch",
    "allowzerorate",
    "description",
    "standardUserDefinedFields",
    "jobsequence",
    "correctiondate"
})
@XmlRootElement(name = "LaborBooking")
public class LaborBooking {

    @XmlElement(name = "BOOKEDHOURSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected BOOKEDHOURSID_Type bookedhoursid;
    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYID activityid;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "DATEWORKED", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME dateworked;
    @XmlElement(name = "OCCUPATIONTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected OCCUPATIONTYPEID_Type occupationtype;
    @XmlElement(name = "EMPLOYEE", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type employee;
    @XmlElement(name = "TRADERATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT traderate;
    @XmlElement(name = "HOURSWORKED", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT hoursworked;
    @XmlElement(name = "STARTTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT starttime;
    @XmlElement(name = "ENDTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT endtime;
    @XmlElement(name = "CORRECTION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "-")
    protected String correction;
    @XmlElement(name = "MULTIEQUIPSPLITINFOBATCH", namespace = "http://schemas.datastream.net/MP_fields")
    protected MULTIEQUIPSPLITINFOBATCH multiequipsplitinfobatch;
    @XmlElement(name = "ALLOWZERORATE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String allowzerorate;
    @XmlElement(name = "DESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String description;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "CORRECTIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME correctiondate;

    /**
     * Gets the value of the bookedhoursid property.
     * 
     * @return
     *     possible object is
     *     {@link BOOKEDHOURSID_Type }
     *     
     */
    public BOOKEDHOURSID_Type getBOOKEDHOURSID() {
        return bookedhoursid;
    }

    /**
     * Sets the value of the bookedhoursid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BOOKEDHOURSID_Type }
     *     
     */
    public void setBOOKEDHOURSID(BOOKEDHOURSID_Type value) {
        this.bookedhoursid = value;
    }

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the dateworked property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEWORKED() {
        return dateworked;
    }

    /**
     * Sets the value of the dateworked property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEWORKED(DATETIME value) {
        this.dateworked = value;
    }

    /**
     * Gets the value of the occupationtype property.
     * 
     * @return
     *     possible object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public OCCUPATIONTYPEID_Type getOCCUPATIONTYPE() {
        return occupationtype;
    }

    /**
     * Sets the value of the occupationtype property.
     * 
     * @param value
     *     allowed object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public void setOCCUPATIONTYPE(OCCUPATIONTYPEID_Type value) {
        this.occupationtype = value;
    }

    /**
     * Gets the value of the employee property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Sets the value of the employee property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Gets the value of the traderate property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTRADERATE() {
        return traderate;
    }

    /**
     * Sets the value of the traderate property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTRADERATE(AMOUNT value) {
        this.traderate = value;
    }

    /**
     * Gets the value of the hoursworked property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getHOURSWORKED() {
        return hoursworked;
    }

    /**
     * Sets the value of the hoursworked property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setHOURSWORKED(AMOUNT value) {
        this.hoursworked = value;
    }

    /**
     * Gets the value of the starttime property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSTARTTIME() {
        return starttime;
    }

    /**
     * Sets the value of the starttime property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSTARTTIME(AMOUNT value) {
        this.starttime = value;
    }

    /**
     * Gets the value of the endtime property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getENDTIME() {
        return endtime;
    }

    /**
     * Sets the value of the endtime property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setENDTIME(AMOUNT value) {
        this.endtime = value;
    }

    /**
     * Gets the value of the correction property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCORRECTION() {
        return correction;
    }

    /**
     * Sets the value of the correction property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCORRECTION(String value) {
        this.correction = value;
    }

    /**
     * Gets the value of the multiequipsplitinfobatch property.
     * 
     * @return
     *     possible object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public MULTIEQUIPSPLITINFOBATCH getMULTIEQUIPSPLITINFOBATCH() {
        return multiequipsplitinfobatch;
    }

    /**
     * Sets the value of the multiequipsplitinfobatch property.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public void setMULTIEQUIPSPLITINFOBATCH(MULTIEQUIPSPLITINFOBATCH value) {
        this.multiequipsplitinfobatch = value;
    }

    /**
     * Gets the value of the allowzerorate property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLOWZERORATE() {
        return allowzerorate;
    }

    /**
     * Sets the value of the allowzerorate property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLOWZERORATE(String value) {
        this.allowzerorate = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the jobsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Sets the value of the jobsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Gets the value of the correctiondate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCORRECTIONDATE() {
        return correctiondate;
    }

    /**
     * Sets the value of the correctiondate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCORRECTIONDATE(DATETIME value) {
        this.correctiondate = value;
    }

}

==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_entities/laborbooking_001/LaborBooking.java <==

package net.datastream.schemas.mp_entities.laborbooking_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.BOOKEDHOURSID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.MULTIEQUIPSPLITINFOBATCH;
import net.datastream.schemas.mp_fields.OCCUPATIONTYPEID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BOOKEDHOURSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEWORKED"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OCCUPATIONTYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADERATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HOURSWORKED"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENDTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CORRECTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MULTIEQUIPSPLITINFOBATCH" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOWZERORATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CORRECTIONDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "bookedhoursid",
    "activityid",
    "tradeid",
    "departmentid",
    "dateworked",
    "occupationtype",
    "employee",
    "traderate",
    "hoursworked",
    "starttime",
    "endtime",
    "correction",
    "multiequipsplitinfobatch",
    "allowzerorate",
    "description",
    "standardUserDefinedFields",
    "jobsequence",
    "correctiondate"
})
@XmlRootElement(name = "LaborBooking")
public class LaborBooking {

    @XmlElement(name = "BOOKEDHOURSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected BOOKEDHOURSID_Type bookedhoursid;
    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYID activityid;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "DATEWORKED", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME dateworked;
    @XmlElement(name = "OCCUPATIONTYPE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected OCCUPATIONTYPEID_Type occupationtype;
    @XmlElement(name = "EMPLOYEE", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type employee;
    @XmlElement(name = "TRADERATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT traderate;
    @XmlElement(name = "HOURSWORKED", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT hoursworked;
    @XmlElement(name = "STARTTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT starttime;
    @XmlElement(name = "ENDTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT endtime;
    @XmlElement(name = "CORRECTION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "-")
    protected String correction;
    @XmlElement(name = "MULTIEQUIPSPLITINFOBATCH", namespace = "http://schemas.datastream.net/MP_fields")
    protected MULTIEQUIPSPLITINFOBATCH multiequipsplitinfobatch;
    @XmlElement(name = "ALLOWZERORATE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "true")
    protected String allowzerorate;
    @XmlElement(name = "DESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String description;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "CORRECTIONDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME correctiondate;

    /**
     * Obtient la valeur de la propriété bookedhoursid.
     * 
     * @return
     *     possible object is
     *     {@link BOOKEDHOURSID_Type }
     *     
     */
    public BOOKEDHOURSID_Type getBOOKEDHOURSID() {
        return bookedhoursid;
    }

    /**
     * Définit la valeur de la propriété bookedhoursid.
     * 
     * @param value
     *     allowed object is
     *     {@link BOOKEDHOURSID_Type }
     *     
     */
    public void setBOOKEDHOURSID(BOOKEDHOURSID_Type value) {
        this.bookedhoursid = value;
    }

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété dateworked.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEWORKED() {
        return dateworked;
    }

    /**
     * Définit la valeur de la propriété dateworked.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEWORKED(DATETIME value) {
        this.dateworked = value;
    }

    /**
     * Obtient la valeur de la propriété occupationtype.
     * 
     * @return
     *     possible object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public OCCUPATIONTYPEID_Type getOCCUPATIONTYPE() {
        return occupationtype;
    }

    /**
     * Définit la valeur de la propriété occupationtype.
     * 
     * @param value
     *     allowed object is
     *     {@link OCCUPATIONTYPEID_Type }
     *     
     */
    public void setOCCUPATIONTYPE(OCCUPATIONTYPEID_Type value) {
        this.occupationtype = value;
    }

    /**
     * Obtient la valeur de la propriété employee.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Définit la valeur de la propriété employee.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Obtient la valeur de la propriété traderate.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTRADERATE() {
        return traderate;
    }

    /**
     * Définit la valeur de la propriété traderate.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTRADERATE(AMOUNT value) {
        this.traderate = value;
    }

    /**
     * Obtient la valeur de la propriété hoursworked.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getHOURSWORKED() {
        return hoursworked;
    }

    /**
     * Définit la valeur de la propriété hoursworked.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setHOURSWORKED(AMOUNT value) {
        this.hoursworked = value;
    }

    /**
     * Obtient la valeur de la propriété starttime.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSTARTTIME() {
        return starttime;
    }

    /**
     * Définit la valeur de la propriété starttime.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSTARTTIME(AMOUNT value) {
        this.starttime = value;
    }

    /**
     * Obtient la valeur de la propriété endtime.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getENDTIME() {
        return endtime;
    }

    /**
     * Définit la valeur de la propriété endtime.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setENDTIME(AMOUNT value) {
        this.endtime = value;
    }

    /**
     * Obtient la valeur de la propriété correction.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCORRECTION() {
        return correction;
    }

    /**
     * Définit la valeur de la propriété correction.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCORRECTION(String value) {
        this.correction = value;
    }

    /**
     * Obtient la valeur de la propriété multiequipsplitinfobatch.
     * 
     * @return
     *     possible object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public MULTIEQUIPSPLITINFOBATCH getMULTIEQUIPSPLITINFOBATCH() {
        return multiequipsplitinfobatch;
    }

    /**
     * Définit la valeur de la propriété multiequipsplitinfobatch.
     * 
     * @param value
     *     allowed object is
     *     {@link MULTIEQUIPSPLITINFOBATCH }
     *     
     */
    public void setMULTIEQUIPSPLITINFOBATCH(MULTIEQUIPSPLITINFOBATCH value) {
        this.multiequipsplitinfobatch = value;
    }

    /**
     * Obtient la valeur de la propriété allowzerorate.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLOWZERORATE() {
        return allowzerorate;
    }

    /**
     * Définit la valeur de la propriété allowzerorate.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLOWZERORATE(String value) {
        this.allowzerorate = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

    /**
     * Obtient la valeur de la propriété standardUserDefinedFields.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Définit la valeur de la propriété standardUserDefinedFields.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété correctiondate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getCORRECTIONDATE() {
        return correctiondate;
    }

    /**
     * Définit la valeur de la propriété correctiondate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setCORRECTIONDATE(DATETIME value) {
        this.correctiondate = value;
    }

}
